LEGWORK
=======

.. toctree::
   :maxdepth: 4



.. automodapi:: legwork.evol

.. tip::
    Feeling a bit spun around by all this binary evolution? Check out our
    tutorial on using functions in the ``evol`` module `here! <notebooks/Evolution.ipynb>`__

.. automodapi:: legwork.psd

.. automodapi:: legwork.snr

.. automodapi:: legwork.source

.. tip::
    Unable to find the source of your issues? Never fear! Check out our
    tutorial on using the Source class `here! <notebooks/Source.ipynb>`__

.. automodapi:: legwork.strain

.. tip::
    Feeling a little strained trying to parse these docs? Check out our
    tutorial on using functions in the ``strain`` module `here! <notebooks/Strains.ipynb>`__

.. automodapi:: legwork.utils

.. automodapi:: legwork.visualisation

.. tip::
    Not quite sure how things are working vis-à-vis visualisation? Check out our
    tutorial on using functions in the ``visualisation`` module `here! <notebooks/Visualisation.ipynb>`__